'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-9f949333.js');
const utils = require('./utils-60214ddc.js');

const buttonCss = ".ibk-button{border:none;outline:none;appearance:none;background-color:transparent;display:inline-flex;justify-content:center;align-items:center;padding:0 30px;border-radius:4px;cursor:pointer;border:2px solid transparent;text-decoration:none;box-sizing:border-box;transition:background-color var(--fast), border-color var(--fast)}.ibk-button *{box-sizing:border-box}.ibk-button:active{transform:translateY(1px)}.ibk-button__text{font-weight:500;font-family:var(--fontGeometria);transition:color var(--fast)}.ibk-button--primary{background-color:var(--primaryGreen1);color:white}.ibk-button--primary:hover{background-color:var(--primaryGreen2)}.ibk-button--secondary{border-color:var(--primaryGreen1);color:var(--primaryGreen1)}.ibk-button--secondary:hover{border-color:var(--primaryGreen2);color:var(--primaryGreen2)}.ibk-button--tertiary{color:var(--primaryGreen1)}.ibk-button--tertiary:hover{color:var(--primaryGreen2)}.ibk-button--small{height:40px;font-size:12px;padding:0 20px}.ibk-button--medium{height:48px;font-size:14px}.ibk-button--large{height:56px;font-size:14px}.ibk-button--full{width:100%}@media screen and (max-width: 360px){.ibk-button--small{height:32px}.ibk-button--medium{height:44px}.ibk-button--large{height:48px}}.ibk-button__loader{display:inline-block;width:20px;height:20px;border:2px solid white;border-radius:50%;animation:ibk-button-loader 500ms linear infinite;pointer-events:none}@keyframes ibk-button-loader{0%{transform:rotate(0deg)}0%{transform:rotate(-360deg)}}.ibk-button--primary .ibk-button__loader{border-top-color:rgba(255,255,255,0.2);border-left-color:rgba(255,255,255,0.2);border-right-color:rgba(255,255,255,0.2)}.ibk-button--secondary .ibk-button__loader,.ibk-button--tertiary .ibk-button__loader{border-top-color:var(--primaryGreen1);border-left-color:var(--primaryGreen1);border-right-color:var(--primaryGreen1)}.ibk-button--negative.ibk-button--primary{background-color:white;color:var(--primaryGreen1)}.ibk-button--negative.ibk-button--primary:hover{background-color:var(--gray5)}.ibk-button--negative.ibk-button--primary:hover .ibk-button__text{color:var(--primaryGreen2)}.ibk-button--negative.ibk-button--primary .ibk-button__loader{border-top-color:var(--primaryGreen4);border-left-color:var(--primaryGreen4);border-right-color:var(--primaryGreen4);border-bottom-color:var(--primaryGreen1)}.ibk-button--negative.ibk-button--primary.ibk-button--disable{background-color:var(--primaryGreen2)}.ibk-button--negative.ibk-button--primary .ibk-button__text{color:var(--primaryGreen1)}.ibk-button--negative.ibk-button--secondary{border-color:white}.ibk-button--negative.ibk-button--secondary:hover{border-color:var(--gray5)}.ibk-button--negative.ibk-button--secondary:hover .ibk-button__text{color:var(--gray5)}.ibk-button--negative.ibk-button--secondary .ibk-button__text{color:white}.ibk-button--negative.ibk-button--secondary .ibk-button__loader{border-top-color:var(--gray4);border-left-color:var(--gray4);border-right-color:var(--gray4);border-bottom-color:var(--gray1)}.ibk-button--negative.ibk-button--secondary:hover .ibk-button__text{color:var(--gray5)}.ibk-button--negative.ibk-button--tertiary.ibk-button--disable{border-color:var(--primaryGreen2)}.ibk-button--negative.ibk-button--tertiary .ibk-button__text{color:var(--primaryGreen1)}.ibk-button--negative.ibk-button--tertiary .ibk-button__text{color:white}.ibk-button--negative.ibk-button--tertiary .ibk-button__loader{border-top-color:var(--gray4);border-left-color:var(--gray4);border-right-color:var(--gray4);border-bottom-color:var(--gray1)}.ibk-button--negative.ibk-button--tertiary.ibk-button--disable .ibk-button__text{color:var(--primaryGreen1)}.ibk-button--disable{cursor:default;pointer-events:none}.ibk-button--disable.ibk-button--primary{background-color:var(--gray4);color:var(--gray2)}.ibk-button--disable.ibk-button--secondary{border-color:var(--gray4);color:var(--gray2)}.ibk-button--disable.ibk-button--tertiary{color:var(--gray2)}";

const IbkButton = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.onclick = index.createEvent(this, "onclick", 7);
    /**
     * <strong>primary:</strong> Fondo de color con texto blanco <br>
     * <strong>secondary:</strong> Fondo transparente con borde y texto verde <br>
     * <strong>tertiary:</strong> Texto verde sin fondo ni borde
     */
    this.appearance = 'primary';
    /** Alto del botón, 40px, 48px y 56px respectivamente en desktop y 32px, 44px, 48px en mobile */
    this.size = 'medium';
    /** Define el tipo del botón, se usarán los tipos nativos */
    this.type = 'button';
    /** Determina si el botón se encuentra sobre un fondo oscuro */
    this.negative = false;
    /** Cuando está en true, se mostrará un icono con una animación de carga. */
    this.loading = false;
    /** Determina si usará el 100% del espacio disponible */
    this.full = false;
    /** Determina si le botón se encuentra deshabilitado */
    this.disable = false;
    /** Determina si el enlace se abre en una nueva ventana o en la misma */
    this.hrefTarget = '_self';
  }
  componentDidLoad() {
    setTimeout(() => {
      this._buttonElement = this.host.querySelector('.ibk-button');
      this._sizeButton = this._buttonElement.getBoundingClientRect().width;
    }, 100);
  }
  onLoadingChange(loading) {
    if (loading && loading === true && !this.href) {
      this._buttonElement.style.width = `${this._sizeButton}px`;
    }
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return utils.modifiersToClass('ibk-button', [
      this.appearance,
      this.size,
      { full: this.full },
      { disable: this.disable },
      { negative: this.negative }
    ]);
  }
  render() {
    if (this.href) {
      return (index.h("a", { class: this.containerClass(), href: this.href, onClick: this.onclick.emit, target: this.hrefTarget }, index.h("span", { class: "ibk-button__text" }, this.text)));
    }
    else {
      return (index.h("button", { class: this.containerClass(), type: this.type, onClick: this.onclick.emit }, !this.loading ?
        index.h("span", { class: "ibk-button__text" }, this.text)
        :
          index.h("span", { class: "ibk-button__loader" })));
    }
  }
  get host() { return index.getElement(this); }
  static get watchers() { return {
    "loading": ["onLoadingChange"]
  }; }
};
IbkButton.style = buttonCss;

const checkboxCss = ".ibk-checkbox{padding:5px 0}.ibk-checkbox *{box-sizing:border-box}.ibk-checkbox__hidden{display:none}.ibk-checkbox__label{display:inline-flex;align-items:flex-start;color:var(--grayText);cursor:pointer}.ibk-checkbox__icon{display:inline-flex;align-items:center;justify-content:center;min-height:18px;min-width:18px;border:2px solid var(--gray4);border-radius:3px;margin-right:7px}.ibk-checkbox__check{color:white;font-size:9px;width:0;overflow:hidden;transition:var(--slow);text-align:center;transform:translateX(-3px)}.ibk-checkbox__label:active{transform:translateY(1px)}.ibk-checkbox__text{font-family:var(--fontGeometria);font-size:14px;font-weight:500;line-height:18px}.ibk-checkbox__text a{text-decoration:none;color:var(--primaryGreen1)}.ibk-checkbox__error-message{color:var(--extendedWatermelon1);font-size:12px;font-family:var(--fontMontserrat);font-weight:500;min-height:15px;margin-top:7px;display:block}.ibk-checkbox--icon-only .ibk-checkbox__icon{margin:0}.ibk-checkbox--checked .ibk-checkbox__icon{background-color:var(--primaryGreen1);border-color:var(--primaryGreen1)}.ibk-checkbox--checked .ibk-checkbox__check{color:white;width:100%;transform:translateX(0)}.ibk-checkbox--disabled{pointer-events:none}.ibk-checkbox--disabled .ibk-checkbox__icon{background-color:var(--gray4);border-color:var(--gray2)}.ibk-checkbox--disabled.ibk-checkbox--checked .ibk-checkbox__icon{border-color:var(--gray4)}.ibk-checkbox--disabled .ibk-checkbox__check{color:var(--gray2)}.ibk-checkbox--error .ibk-checkbox__icon{border-color:var(--extendedWatermelon1)}.ibk-checkbox--right .ibk-checkbox__label{justify-content:space-between}.ibk-checkbox--right .ibk-checkbox__icon{margin-right:0;margin-left:7px;order:2}.ibk-checkbox--outline .ibk-checkbox__label{border:1px solid var(--gray4);border-radius:4px;padding:10px}.ibk-checkbox--full .ibk-checkbox__label{width:100%}.ibk-checkbox--focus .ibk-checkbox__icon{border-color:var(--primaryGreen1)}";

const IbkCheckbox = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.onchecked = index.createEvent(this, "onchecked", 7);
    /** Estado activo del checkbox */
    this.checked = false;
    /** Estado inactivo del checkbox */
    this.disabled = false;
    /** Error en el checkbox */
    this.error = false;
    /** Cuando se encuentra dentro de un "ibk-form" al hacer submit si el checkbox se encuentra deseleccionado, mostrará un mensaje de error */
    this.required = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = 'Este campo es requerido';
    /** Determina si el checkbox ocupa el 100% de la pantalla */
    this.full = false;
    /** Determina la posición del ícono */
    this.iconPosition = 'left';
    /** El checkbox se verá envuelto en una caja */
    this.outline = false;
    /** El checkbox estará agrupado en "ibk-checkbox-group" */
    this._grouped = false;
    /** Estado focus del checkbox */
    this._focus = false;
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return utils.modifiersToClass('ibk-checkbox', [
        this.iconPosition,
        { outline: this.outline },
        { checked: this.checked },
        { disabled: this.disabled },
        { error: this.error },
        { full: this.full },
        { focus: this._focus },
        { 'icon-only': !this.label }
      ]);
    };
  }
  componentWillLoad() {
    this.groupVerification();
  }
  /** Detecta cuando el estado del checkbox cambia */
  changeCheckbox() {
    if (this.checked) {
      this.host.removeAttribute('checked');
    }
    else {
      this.host.setAttribute('checked', '');
    }
    this.host.removeAttribute('error');
    this.onchecked.emit({
      checked: this.checked,
      value: this.value
    });
  }
  onPressEnter(e) {
    if (e.keyCode == 13) {
      if (this.checked) {
        this.host.removeAttribute('checked');
      }
      else {
        this.host.setAttribute('checked', '');
      }
    }
  }
  /** Verificar si el checkbox se encuentra agrupado */
  groupVerification() {
    const grouper = this.host.closest('ibk-checkbox-group');
    this._grouped = grouper != null ? true : false;
  }
  onRadioFocusIn() { this._focus = true; }
  onRadioFocusOut() { this._focus = false; }
  render() {
    return (index.h("div", { class: this.containerClass() }, index.h("label", { class: "ibk-checkbox__label" }, index.h("input", { class: "ibk-checkbox__hidden", checked: this.checked, type: "checkbox", value: this.value }), index.h("span", { class: "ibk-checkbox__icon" }, index.h("i", { class: "ibk-checkbox__check icon-xs-check" })), index.h("span", { class: "ibk-checkbox__text", innerHTML: this.label })), (!this._grouped && this.error) && index.h("span", { class: "ibk-checkbox__error-message" }, this.requiredMessage)));
  }
  get host() { return index.getElement(this); }
};
IbkCheckbox.style = checkboxCss;

const dropdownCss = ".ibk-dropdown{width:100%;box-sizing:border-box;position:relative;color:var(--grayText)}.ibk-dropdown *{box-sizing:border-box}.ibk-dropdown__label{font-family:var(--fontGeometria);font-size:14px;padding-bottom:5px;display:block;font-weight:500;color:var(--gray1)}.ibk-dropdown__subtitle{font-family:var(--fontMontserrat);font-size:14px;font-weight:500;padding-bottom:7px;display:block}.ibk-dropdown__input{display:flex;align-items:center;width:100%;border:1px solid var(--gray4);border-radius:4px;height:48px;transition:var(--fast);overflow:hidden;background-color:white;cursor:pointer}@media screen and (max-width: 360px){.ibk-dropdown__input{height:44px}}.ibk-dropdown__input:hover{border-color:var(--gray3)}.ibk-dropdown__value{width:100%;appearance:none;-webkit-appearance:none;-moz-appearance:none;border:none;outline:none;display:block;height:100%;padding:0 0 0 15px;font-family:var(--fontGeometria);font-size:16px;font-weight:500;background-color:transparent;cursor:pointer;text-overflow:ellipsis}.ibk-dropdown__value::placeholder{color:var(--gray2);font-weight:400}.ibk-dropdown__card-image{display:inline-block;width:40px;margin-left:15px}.ibk-dropdown__icon-down{padding:15px;color:var(--primaryGreen1);pointer-events:none;font-size:7px;transition:var(--fast)}.ibk-dropdown__mobile{position:relative}.ibk-dropdown__mobile .ibk-dropdown__icon-down{position:absolute;top:calc(50% - (32px / 2));right:0}.ibk-dropdown__select{display:block;height:48px;appearance:none;-webkit-appearance:none;-moz-appearance:none;outline:none;border:1px solid var(--gray4);width:100%;border-radius:4px;padding:0 15px;font-family:var(--fontGeometria);font-size:16px}.ibk-dropdown__select-option{font-size:14px}@media screen and (max-width: 360px){.ibk-dropdown__select{height:44px}}.ibk-dropdown--error .ibk-dropdown__input,.ibk-dropdown--error .ibk-dropdown__select{border-color:var(--extendedWatermelon1)}.ibk-dropdown--error.ibk-dropdown--focus .ibk-dropdown__input{box-shadow:inset 0 0 0 0.5px var(--extendedWatermelon1)}.ibk-dropdown--error .ibk-dropdown__trailing-icon,.ibk-dropdown--error .ibk-dropdown__leading-icon{color:var(--extendedWatermelon1)}.ibk-dropdown__error-message{font-family:var(--fontMontserrat);font-size:12px;color:var(--extendedWatermelon1);font-weight:500;margin-top:7px;display:block;min-height:15px}.ibk-dropdown--disabled{cursor:default;pointer-events:none}.ibk-dropdown--disabled .ibk-dropdown__input,.ibk-dropdown--disabled .ibk-dropdown__select{background-color:var(--gray5)}.ibk-dropdown--disabled .ibk-dropdown__icon-down{color:var(--gray2)}.ibk-dropdown--disabled .ibk-dropdown__select{color:var(--gray2)}.ibk-dropdown__dropitems{width:100%;min-width:max-content;position:absolute;top:calc(100% - 23px);border:1px solid var(--gray4);border-radius:0 0 4px 4px;display:none;z-index:1;box-shadow:0 2px 4px 0 var(--gray4);overflow:hidden;background-color:white}.ibk-dropdown__dropitems ibk-dropdown-item:last-child .ibk-dropdown-item{border-bottom:0;line-height:48px}@media screen and (max-width: 360px){.ibk-dropdown__dropitems{top:43px}.ibk-dropdown__dropitems ibk-dropdown-item:last-child .ibk-dropdown-item{line-height:44px}}.ibk-dropdown__dropitems-list{margin:0;padding:0;max-height:240px;overflow:auto}.ibk-dropdown__dropitems-list::-webkit-scrollbar{width:5px;background-color:white}.ibk-dropdown__dropitems-list::-webkit-scrollbar-thumb{background-color:var(--primaryGreen1);border-radius:3px}@media screen and (max-width: 360px){.ibk-dropdown__dropitems-list{max-height:220px}}.ibk-dropdown--open .ibk-dropdown__input{border-bottom-right-radius:0;border-bottom-left-radius:0;box-shadow:0 2px 4px 0 var(--gray4)}.ibk-dropdown--open .ibk-dropdown__dropitems{display:block}.ibk-dropdown--open .ibk-dropdown__icon-down{transform:rotate(-180deg)}.ibk-dropdown__searcher{background-color:white;display:flex;align-items:center;justify-content:space-between;padding:0 15px;border-bottom:1px solid var(--gray4)}.ibk-dropdown__searcher-value{width:100%;margin:0 10px;padding:0;appearance:none;-webkit-appearance:none;-moz-appearance:none;border:none;outline:none;height:47px;font-family:var(--fontGeometria);font-size:14px;font-weight:500}@media screen and (max-width: 360px){.ibk-dropdown__searcher-value{height:43px}}.ibk-dropdown__searcher-value::placeholder{color:var(--gray2);font-weight:400}.ibk-dropdown__searcher-icon{color:var(--gray2)}.ibk-dropdown__searcher-erase{color:var(--gray1);cursor:pointer}.ibk-dropdown__searcher-erase:active{transform:translateY(1px)}.ibk-dropdown__trigger{height:48px;display:flex;align-items:center;justify-content:center;appearance:none;-webkit-appearance:none;-moz-appearance:none;outline:none;border:none;background-color:transparent;cursor:pointer;transition:background-color var(--fast)}.ibk-dropdown__trigger:hover{background-color:rgba(0,0,0,0.025)}.ibk-dropdown__trigger:active{transform:translateY(1px)}.ibk-dropdown__trigger-icon{pointer-events:none;font-size:18px;color:var(--primaryGreen1)}.ibk-dropdown--trigger-round,.ibk-dropdown--trigger-box{display:inline-block;width:auto}.ibk-dropdown--trigger-round .ibk-dropdown__dropitems,.ibk-dropdown--trigger-box .ibk-dropdown__dropitems{border-top-right-radius:4px;border-top-left-radius:4px;top:100%}.ibk-dropdown--trigger-round .ibk-dropdown-item,.ibk-dropdown--trigger-box .ibk-dropdown-item{padding-right:50px}.ibk-dropdown--trigger-round .ibk-dropdown__trigger{width:48px;border-radius:50%}.ibk-dropdown--trigger-box .ibk-dropdown__trigger{border-radius:4px;padding:0 10px}.ibk-dropdown__trigger-text{color:var(--primaryGreen1);font-size:14px;font-weight:500;font-family:var(--fontGeometria)}.ibk-dropdown__trigger-space{padding-left:7px}.ibk-dropdown--no-handling-error .ibk-dropdown__dropitems{top:calc(100% - 1px)}";

const IbkDropdown = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.onchange = index.createEvent(this, "onchange", 7);
    /** Texto de ayuda dentro del campo seleccionable del dropdown */
    this.placeholder = 'Seleccione';
    /** Se mostrará un mensaje de error */
    this.error = false;
    /** Cuando se encuentra dentro de un "ibk-form" al hacer submit si el dropdown se encuentra vacío, mostrará un mensaje de error */
    this.required = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = 'Por favor seleccione una opción';
    /** Se agregará un campo de texto al abrir el dropdown donde se podrá ingresar texto y filtrar entre los elementos del dropdown */
    this.searcher = false;
    /** Se agregará un placeholder personalizado al input de busqueda */
    this.searcherPlaceholder = 'Buscar';
    /** El dropdown no se podrá seleccionar */
    this.disabled = false;
    /** Define si el dropdown no contará con manejo de errores. Se omitirá el espacio generado para el mensaje de error */
    this.noHandlingError = false;
    /** Estado que determina si el dropdown se encuentra abierto */
    this._open = false;
    /** El dispositivo es un móvil */
    this._mobileDevice = false;
    /** Determina si el componente se está ejecutando en un dispositivo móvil */
    this.checkDeviceMobile = () => {
      if (/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent)) {
        this._mobileDevice = true;
      }
    };
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return utils.modifiersToClass('ibk-dropdown', [
        { error: this.error },
        { disabled: this.disabled },
        { open: this._open },
        { 'trigger-round': this.triggerIcon != undefined && this.triggerText == undefined },
        { 'trigger-box': this.triggerText != undefined },
        { 'no-handling-error': this.noHandlingError }
      ]);
    };
    /** Abre o cierra el dropdown dependiendo del estado actual */
    this.dropdownHandler = (e) => {
      e.preventDefault();
      e.stopPropagation();
      // Cerrar otros dropdowns que se encuentren abiertos
      const isOpen = this.host.querySelector('.ibk-dropdown').classList.contains('ibk-dropdown--open');
      if (!isOpen && this._open) {
        this._open = false;
      }
      setTimeout(() => {
        const dropitems = document.querySelectorAll('.ibk-dropdown__dropitems');
        Array.from(dropitems, (item) => {
          const otherContainers = item.closest('.ibk-dropdown');
          otherContainers.classList.remove('ibk-dropdown--open');
        });
        this._open = !this._open;
        if (!this._open) {
          const preselected = this.host.querySelector('ibk-dropdown-item[preselected]:not([preselected="false"])');
          if (preselected != null) {
            preselected.removeAttribute('preselected');
          }
        }
        else {
          setTimeout(() => {
            this.setPreselected();
            const searcher = this.host.querySelector('.ibk-dropdown__searcher-value');
            searcher && searcher.focus();
          }, 10);
        }
      }, 10);
    };
    /** Cierra el dropdown al hacer click fuera del mismo */
    this.bodyClick = () => {
      const body = document.querySelector('body');
      body.addEventListener('click', e => {
        const t = e.target;
        const input = t.closest('.ibk-dropdown__input');
        const closest = t.closest('.ibk-dropdown__value');
        const trigger = t.closest('.ibk-dropdown__trigger');
        const searcher = t.closest('.ibk-dropdown__searcher');
        if (this._open && input == null && closest == null && searcher == null && trigger == null) {
          this._open = false;
          let preselected = this.host.querySelector('ibk-dropdown-item[preselected]:not([preselected="false"])');
          if (preselected != null) {
            preselected.removeAttribute('preselected');
          }
        }
      });
    };
    /** Validar si existe algún item pre seleccionado */
    this.setPreselected = () => {
      let preselected = this.host.querySelector('ibk-dropdown-item[selected]:not([selected="false"])');
      if (preselected != null) {
        this._selectedItem = {
          value: preselected.getAttribute('value'),
          label: preselected.getAttribute('label'),
          cardType: preselected.getAttribute('card-type')
        };
        this.moveScrollToSelection(preselected, 'down');
      }
    };
    /** Escucha el evento al seleccionar algún item del dropdown */
    this.listenSlottedEvents = () => {
      const dropitems = this.host.querySelectorAll('ibk-dropdown-item');
      Array.from(dropitems, item => {
        item.addEventListener('onselect', (e) => {
          this._selectedItem = e.detail;
          Array.from(dropitems, d => {
            if (item != d) {
              d.removeAttribute('selected');
            }
          });
          this.clearSearcher();
          this.host.removeAttribute('error');
          this.onchange.emit(this._selectedItem);
          if (this._grouper != null) {
            this._grouper.removeAttribute('error');
          }
        });
      });
    };
    /** Al escribir en el buscador, filtrará entre las opciones */
    this.searchOption = (e) => {
      const t = e.target;
      const dropitems = this.host.querySelectorAll('ibk-dropdown-item');
      if (t.value != '') {
        this._cleared = true;
        Array.from(dropitems, (item) => {
          const label = item.querySelector('.ibk-dropdown-item__label');
          const plain = utils.convertToPlainString(label.innerHTML);
          if (plain.search(t.value) < 0) {
            item.setAttribute('hidden', '');
          }
          else {
            item.removeAttribute('hidden');
          }
        });
      }
      else {
        this.showAllOptions();
      }
    };
    /** Elimina el contenido del buscador */
    this.clearSearcher = () => {
      const searcher = this.host.querySelector('.ibk-dropdown__searcher-value');
      if (searcher != null) {
        searcher.value = '';
        searcher.focus();
        this.showAllOptions();
      }
    };
    /** Muestra todas las opciones que se ocultaron al filtrar usando el buscador */
    this.showAllOptions = () => {
      const dropitems = this.host.querySelectorAll('ibk-dropdown-item');
      Array.from(dropitems, (item) => {
        item.removeAttribute('hidden');
      });
      this._cleared = false;
    };
    /** Verifica que el item preseleccionado se encuentre dentro del espacio visible del scrollbar */
    this.moveScrollToSelection = (preselected, moveTo) => {
      if (this._open) {
        const list = this.host.querySelector('.ibk-dropdown__dropitems-list');
        const itemHeight = list.querySelector('.ibk-dropdown-item').clientHeight;
        const visible = utils.visibilityValidate(preselected, list);
        if (!visible && moveTo == 'down') {
          list.scrollTo({ top: preselected.offsetTop - (list.clientHeight) });
        }
        else if (!visible && moveTo == 'up') {
          list.scrollTo({ top: preselected.offsetTop - itemHeight });
        }
      }
    };
    /** Elimina la preseleccion al hacer focus en el buscador */
    this.deletePreselected = () => {
      const preselected = this.host.querySelector('ibk-dropdown-item[preselected]:not([preselected="false"])');
      if (preselected != null) {
        preselected.removeAttribute('preselected');
      }
    };
    /** Si el dispositivo es mobile, tomará los "ibk-dropdown-items" y los convertirá en "option" */
    this.mobileOptions = () => {
      const items = this.host.querySelectorAll('ibk-dropdown-item');
      let options = [];
      Array.from(items, (it) => {
        let opt = {
          value: it.getAttribute('value'),
          label: it.getAttribute('label'),
          cardType: it.getAttribute('card-type'),
          selected: it.getAttribute('selected')
        };
        options.push(opt);
        it.remove();
      });
      return options;
    };
  }
  componentDidLoad() {
    this.bodyClick();
    this.listenSlottedEvents();
    this.checkDeviceMobile();
  }
  componentWillLoad() {
    this.setPreselected();
    this._grouper = this.host.closest('ibk-form-group');
  }
  /** Usando las flechas de navegación se preselecciona una opcion */
  optionsNavigate(e) {
    if (this._open) {
      // const dropitems = this.host.querySelectorAll('ibk-dropdown-item')
      let preselected = this.host.querySelector('ibk-dropdown-item[preselected]:not([preselected="false"])');
      const itemsLength = this.host.querySelectorAll('ibk-dropdown-item').length;
      // Flecha hacia abajo
      if (e.keyCode == 40) {
        let nextItem;
        if (preselected == null) {
          nextItem = this.host.querySelector('ibk-dropdown-item');
          nextItem = nextItem.matches('[hidden]') ? this.host.querySelector('ibk-dropdown-item:not([hidden])') : nextItem;
        }
        else {
          preselected.removeAttribute('preselected');
          nextItem = utils.nextSibling(preselected, ':not([hidden])');
        }
        if (nextItem == null || nextItem == undefined) {
          nextItem = this.host.querySelector('ibk-dropdown-item:not([hidden])');
        }
        nextItem.setAttribute('preselected', '');
        this.moveScrollToSelection(nextItem, 'down');
      }
      // Flecha hacia arriba
      else if (e.keyCode == 38) {
        let prevItem;
        if (preselected == null) {
          prevItem = this.host.querySelectorAll('ibk-dropdown-item')[itemsLength - 1];
          prevItem = prevItem.matches('[hidden]') ? this.host.querySelectorAll('ibk-dropdown-item:not([hidden])')[itemsLength - 1] : prevItem;
        }
        else {
          preselected.removeAttribute('preselected');
          prevItem = utils.prevSibling(preselected, ':not([hidden])');
        }
        if (prevItem == null || prevItem.classList.contains('ibk-dropdown__searcher')) {
          prevItem = this.host.querySelectorAll('ibk-dropdown-item')[itemsLength - 1];
        }
        prevItem.setAttribute('preselected', '');
        this.moveScrollToSelection(prevItem, 'up');
      }
      // Tecla enter
      else if (e.keyCode == 13) {
        this._selectedItem = {
          value: preselected.getAttribute('value'),
          label: preselected.getAttribute('label'),
          cardType: preselected.getAttribute('card-type')
        };
        const oldSelected = this.host.querySelector('[selected]');
        if (oldSelected != null) {
          oldSelected.removeAttribute('selected');
        }
        const newSelected = this.host.querySelector(`[value="${preselected.getAttribute('value')}"]`);
        newSelected.setAttribute('selected', '');
        this.clearSearcher();
        this.host.removeAttribute('error');
        this._open = false;
        this.onchange.emit(this._selectedItem);
        if (this._grouper != null) {
          this._grouper.removeAttribute('error');
        }
      }
      // Tecla Esc
      else if (e.keyCode == 27) {
        this.clearSearcher();
        this._open = false;
      }
    }
  }
  render() {
    var _a, _b, _c;
    if (!this._mobileDevice) {
      return (index.h("div", { class: this.containerClass(), style: { width: this.width + 'px' } }, this.label && index.h("span", { class: "ibk-dropdown__label" }, this.label), this.subtitle && index.h("span", { class: "ibk-dropdown__subtitle" }, this.subtitle), (this.triggerIcon == undefined && this.triggerText == undefined) ?
        index.h("label", { class: "ibk-dropdown__input", onClick: this.dropdownHandler }, index.h("input", { type: "hidden", value: (_a = this._selectedItem) === null || _a === void 0 ? void 0 : _a.value }), ((_b = this._selectedItem) === null || _b === void 0 ? void 0 : _b.cardType) && index.h("img", { class: "ibk-dropdown__card-image", src: `../assets/images/${this._selectedItem.cardType}.png`, alt: this._selectedItem.cardType }), index.h("input", { class: "ibk-dropdown__value", type: "text", value: (_c = this._selectedItem) === null || _c === void 0 ? void 0 : _c.label, placeholder: this.placeholder, readOnly: true }), index.h("i", { class: "ibk-dropdown__icon-down icon-xs-arrow-down" })) :
        index.h("button", { type: "button", class: "ibk-dropdown__trigger", onClick: this.dropdownHandler }, this.triggerIcon && index.h("i", { style: { color: this.triggerIconColor }, class: 'ibk-dropdown__trigger-icon ' + this.triggerIcon }), this.triggerText && index.h("span", { class: 'ibk-dropdown__trigger-text' + (this.triggerIcon && this.triggerText && ' ibk-dropdown__trigger-space') }, this.triggerText)), (this.triggerIcon == undefined && this.triggerText == undefined && !this.noHandlingError) && index.h("span", { class: "ibk-dropdown__error-message" }, this.error && this.requiredMessage), index.h("div", { class: "ibk-dropdown__dropitems" }, this.searcher &&
        index.h("div", { class: "ibk-dropdown__searcher" }, index.h("i", { class: "ibk-dropdown__searcher-icon icon-m-search" }), index.h("input", { class: "ibk-dropdown__searcher-value", type: "text", placeholder: this.searcherPlaceholder, onInput: this.searchOption, onFocus: this.deletePreselected }), this._cleared && index.h("i", { onClick: this.clearSearcher, class: "ibk-dropdown__searcher-erase icon-m-status-error" })), index.h("ul", { class: "ibk-dropdown__dropitems-list" }, index.h("slot", null)))));
    }
    else {
      return (index.h("div", { class: this.containerClass() }, this.label && index.h("span", { class: "ibk-dropdown__label" }, this.label), this.subtitle && index.h("span", { class: "ibk-dropdown__subtitle" }, this.subtitle), index.h("div", { class: "ibk-dropdown__mobile" }, index.h("select", { class: "ibk-dropdown__select" }, index.h("slot", null), this.placeholder && index.h("option", { disabled: true, selected: true, value: "-1" }, this.placeholder), Array.from(this.mobileOptions(), (option) => {
        return (index.h("option", { class: "ibk-dropdown__select-option", value: option.value, selected: option.selected != null ? true : null }, option.cardType != null ? `${utils.firstCapitalice(option.cardType)} - ` : '', option.label));
      })), index.h("i", { class: "ibk-dropdown__icon-down icon-xs-arrow-down" })), index.h("span", { class: "ibk-dropdown__error-message" }, this.error && this.requiredMessage)));
    }
  }
  get host() { return index.getElement(this); }
};
IbkDropdown.style = dropdownCss;

const dropdownItemCss = ".ibk-dropdown-item{display:flex;align-items:center;line-height:47px;border-bottom:1px solid var(--gray4);background-color:white;padding:0 15px;cursor:pointer;transition:var(--fast);color:var(--grayText)}.ibk-dropdown-item--preselected{background-color:var(--gray5)}.ibk-dropdown-item__label{font-family:var(--fontGeometria);font-size:14px;font-weight:500;pointer-events:none;text-overflow:ellipsis;white-space:nowrap;max-width:100%;display:block;overflow:hidden}.ibk-dropdown-item__card-image{display:inline-block;width:40px;margin-right:12px}.ibk-dropdown-item--selected{background-color:var(--gray5)}.ibk-dropdown-item--selected .ibk-dropdown-item__label{color:var(--primaryGreen1)}.ibk-dropdown-item--hide{display:none}@media screen and (max-width: 360px){.ibk-dropdown-item{line-height:43px}}.ibk-dropdown-item--disabled{pointer-events:none;background-color:var(--gray5);color:var(--gray2)}";

const IbkDropdownItem = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.onselect = index.createEvent(this, "onselect", 7);
    /** Se ocultará la opción de la lista */
    this.hide = false;
    /** Define si el item se mantendrá marcado al ser seleccionado */
    this._keepMarked = false;
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return utils.modifiersToClass('ibk-dropdown-item', [
        { selected: this.selected && !this._keepMarked },
        { hide: this.hide },
        { preselected: this.preselected },
        { disabled: this.disabled }
      ]);
    };
    /** Selecciona el elemento y lo envía al componente padre "ibk-dropdown" */
    this.selectItem = () => {
      this.host.setAttribute('selected', '');
      const item = {
        value: this.value,
        label: this.label,
        cardType: this.cardType
      };
      this.onselect.emit(item);
    };
  }
  componentWillLoad() {
    const keepMarkedAttr = this.host.closest('ibk-dropdown').getAttribute('keep-marked');
    if (keepMarkedAttr != undefined) {
      this._keepMarked = true;
    }
  }
  setPreselected() {
    const parent = this.host.closest('ibk-dropdown');
    const preselected = parent.querySelector('ibk-dropdown-item[preselected]');
    if (preselected != null) {
      preselected.removeAttribute('preselected');
    }
    this.host.setAttribute('preselected', '');
  }
  deletePreselected() {
    this.host.removeAttribute('preselected');
  }
  render() {
    return (index.h("li", { class: this.containerClass(), "data-id": this.value, onClick: this.selectItem }, this.cardType && index.h("img", { class: "ibk-dropdown-item__card-image", src: `../assets/images/${this.cardType.toLowerCase()}.png`, alt: this.cardType }), index.h("span", { class: "ibk-dropdown-item__label", style: { color: this.color } }, this.label)));
  }
  get host() { return index.getElement(this); }
};
IbkDropdownItem.style = dropdownItemCss;

const IbkForm = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.onsubmit = index.createEvent(this, "onsubmit", 7);
    this.submitForm = (e) => {
      e.preventDefault();
      let wrongElements = 0;
      this._formElements.forEach((element) => {
        var _a;
        if (element.tagName.toLowerCase() == 'ibk-form-group') {
          const fields = element.querySelectorAll('ibk-textfield, ibk-dropdown');
          const required = element.getAttribute('required');
          const joined = element.getAttribute('joined');
          let empty = false;
          fields.forEach((field) => {
            if (required != null) {
              field.setAttribute('required', '');
            }
            if (joined != null) {
              if (field.tagName.toLowerCase() == 'ibk-textfield') {
                const value = field.querySelector('.ibk-textfield__value').value;
                if (value == '') {
                  empty = true;
                }
              }
              else if (field.tagName.toLowerCase() == 'ibk-dropdown') {
                const value = field.querySelector('.ibk-dropdown__value').value;
                if (value == '') {
                  empty = true;
                }
              }
            }
          });
          if (empty && required != null) {
            element.setAttribute('error', '');
          }
        }
        if (element.tagName.toLowerCase() == 'ibk-textfield') {
          const required = element.getAttribute('required');
          const type = (_a = element.getAttribute('type')) !== null && _a !== void 0 ? _a : 'text';
          const value = element.querySelector('.ibk-textfield__value').value;
          let regex;
          if (required != null && value == '') {
            element.setAttribute('error', '');
            wrongElements++;
          }
          else {
            switch (type) {
              case 'dni':
                regex = utils.regexValidators.dni;
                break;
              case 'document':
                regex = utils.regexValidators.document;
                break;
              case 'email':
                regex = utils.regexValidators.email;
                break;
              case 'number':
                regex = utils.regexValidators.numberFormat;
                break;
              case 'expiration':
                regex = utils.regexValidators.expiration;
                break;
              case 'cvv':
                regex = utils.regexValidators.cvv;
                break;
              case 'phone':
                regex = utils.regexValidators.number;
                break;
            }
            if (value != '' && regex != undefined && !regex.test(value)) {
              element.setAttribute('error', '');
              wrongElements++;
            }
          }
        }
        else if (element.tagName.toLowerCase() == 'ibk-dropdown') {
          const required = element.getAttribute('required');
          const value = element.querySelector('.ibk-dropdown__value').value;
          if (required != null && value == '') {
            element.setAttribute('error', '');
            wrongElements++;
          }
        }
        else if (element.tagName.toLowerCase() == 'ibk-checkbox') {
          const required = element.getAttribute('required');
          const checked = element.getAttribute('checked');
          const grouper = element.closest('ibk-checkbox-group');
          if (required != null && checked == null && grouper == null) {
            element.setAttribute('error', '');
            wrongElements++;
          }
        }
        else if (element.tagName.toLowerCase() == 'ibk-checkbox-group') {
          const required = element.getAttribute('required');
          const checked = element.querySelectorAll('ibk-checkbox[checked]');
          if (required != null && checked.length == 0) {
            element.setAttribute('error', '');
            Array.from(element.querySelectorAll('ibk-checkbox'), (checkbox) => checkbox.setAttribute('error', ''));
            wrongElements++;
          }
        }
        else if (element.tagName.toLowerCase() == 'ibk-radio') {
          const required = element.getAttribute('required');
          const selected = element.getAttribute('selected');
          const grouper = element.closest('ibk-radio-group');
          if (required != null && selected == null && grouper == null) {
            element.setAttribute('error', '');
            wrongElements++;
          }
        }
        else if (element.tagName.toLowerCase() == 'ibk-radio-group') {
          const required = element.getAttribute('required');
          const selected = element.querySelector('ibk-radio[selected]');
          if (required != null && selected == null) {
            element.setAttribute('error', '');
            Array.from(element.querySelectorAll('ibk-radio'), (radio) => radio.setAttribute('error', ''));
            wrongElements++;
          }
        }
        else if (element.tagName.toLowerCase() == 'ibk-calendar') {
          const required = element.getAttribute('required');
          const value = element.querySelector('.ibk-calendar__input').value;
          const multiselect = element.getAttribute('multiselect');
          let error = false;
          if (multiselect != null) {
            const splitted = value.split('-');
            if (splitted.length == 1 || (splitted.length == 2 && splitted[1].trim() == '')) {
              error = true;
            }
          }
          else {
            if (value == '') {
              error = true;
            }
          }
          if (required != null && error) {
            element.setAttribute('error', '');
            wrongElements++;
          }
        }
      });
      this.onsubmit.emit(wrongElements == 0);
    };
  }
  componentDidLoad() {
    this._formElements = this.host.querySelectorAll('ibk-textfield, ibk-form-group, ibk-dropdown, ibk-checkbox, ibk-checkbox-group, ibk-radio, ibk-radio-group, ibk-calendar');
  }
  render() {
    return (index.h("form", { class: "ibk-form", onSubmit: (e) => this.submitForm(e) }, index.h("slot", null)));
  }
  get host() { return index.getElement(this); }
};
IbkForm.style = {
  0: ".ibk-form { display: block; }"
};

const formGroupCss = ".ibk-form-group{box-sizing:border-box}.ibk-form-group *{box-sizing:border-box}.ibk-form-group__label{color:var(--gray1);font-size:14px;font-family:var(--fontGeometria);font-weight:500;margin-bottom:7px;display:block}.ibk-form-group__subtitle{font-family:var(--fontMontserrat);color:var(--grayText);font-size:14px;font-weight:500;padding-bottom:7px;display:block}.ibk-form-group__list{display:flex;align-items:flex-start;justify-content:space-between}.ibk-form-group ibk-textfield,.ibk-form-group ibk-dropdown{width:100%}.ibk-form-group:not(.ibk-form-group--joined) ibk-textfield:not(:last-child),.ibk-form-group:not(.ibk-form-group--joined) ibk-dropdown:not(:last-child){margin-right:15px}.ibk-form-group__error-message{font-family:var(--fontMontserrat);font-size:12px;color:var(--extendedWatermelon1);font-weight:500;margin-top:7px;display:block;min-height:15px}.ibk-form-group--joined .ibk-textfield__input,.ibk-form-group--joined .ibk-dropdown__input{border-radius:0}.ibk-form-group--joined ibk-textfield:first-child .ibk-textfield__input,.ibk-form-group--joined ibk-dropdown:first-child .ibk-dropdown__input{border-radius:4px 0 0 4px;position:relative}.ibk-form-group--joined ibk-textfield:not(:last-child) .ibk-textfield__input,.ibk-form-group--joined ibk-dropdown:not(:last-child) .ibk-dropdown__input{border-right:0}.ibk-form-group--joined ibk-textfield:last-child .ibk-textfield__input,.ibk-form-group--joined ibk-dropdown:last-child .ibk-dropdown__input{border-radius:0 4px 4px 0}.ibk-form-group--joined ibk-textfield:not(:last-child):hover+ibk-textfield .ibk-textfield__input,.ibk-form-group--joined ibk-textfield:not(:last-child):hover+ibk-dropdown .ibk-dropdown__input,.ibk-form-group--joined ibk-dropdown:not(:last-child):hover+ibk-textfield .ibk-textfield__input,.ibk-form-group--joined ibk-dropdown:not(:last-child):hover+ibk-dropdown .ibk-dropdown__input{border-left:1px solid var(--gray3)}";

const IbkFormGroup = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /** Define si los campos se encontrarán unidos, sin espaceios entre si */
    this.joined = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = "Los campos son requeridos";
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return utils.modifiersToClass('ibk-form-group', [
        { joined: this.joined }
      ]);
    };
    this.setFocus = () => {
      this._allFields.forEach((field) => {
        field.addEventListener('onfocus', (e) => {
          var _a;
          const next = (_a = field.nextElementSibling) === null || _a === void 0 ? void 0 : _a.querySelector('.ibk-textfield__input, .ibk-dropdown__input');
          if (next && field.getAttribute('error') == null) {
            if (e.detail == 'in') {
              next.style.borderLeft = '1px solid #05be50';
            }
            else if (e.detail == 'out') {
              next.removeAttribute('style');
            }
          }
        });
      });
    };
    /** Elimina los contenedores de los mensajes de error de los campos en el grupo */
    this.configFieldProperties = () => {
      var _a;
      const _fieldsWidth = (_a = this.fieldsWidth) === null || _a === void 0 ? void 0 : _a.split(',');
      this._allFields.forEach((field, index) => {
        if (_fieldsWidth && _fieldsWidth[index]) {
          field.style.width = `${_fieldsWidth[index]}%`;
        }
        if (this.error) {
          field.setAttribute('error', '');
        }
        else {
          field.removeAttribute('error');
        }
        if (this.joined) {
          field.setAttribute('no-handling-error', '');
        }
        else {
          if (this.required) {
            field.setAttribute('required', '');
          }
          else {
            field.removeAttribute('error');
          }
        }
      });
    };
  }
  componentWillLoad() {
    this._allFields = this.host.querySelectorAll('ibk-textfield, ibk-dropdown');
    this.setFocus();
    this.configFieldProperties();
  }
  watchingError() {
    this.configFieldProperties();
  }
  render() {
    return (index.h("div", { class: this.containerClass() }, this.label && index.h("span", { class: "ibk-form-group__label" }, this.label), this.subtitle && index.h("span", { class: "ibk-form-group__subtitle" }, this.subtitle), index.h("div", { class: "ibk-form-group__list" }, index.h("slot", null)), this.joined && index.h("span", { class: "ibk-form-group__error-message" }, this.error && this.requiredMessage)));
  }
  get host() { return index.getElement(this); }
  static get watchers() { return {
    "error": ["watchingError"]
  }; }
};
IbkFormGroup.style = formGroupCss;

const tableCss = ".ibk-table{width:100%;box-sizing:border-box;color:var(--grayText);font-family:var(--fontMontserrat);font-size:14px;text-align:left}.ibk-table *{box-sizing:border-box}.ibk-table__body{width:100%;border-radius:4px;overflow:auto;box-shadow:0 2px 4px 0 var(--gray4)}.ibk-table__body::-webkit-scrollbar{height:4px;width:4px;background-color:var(--gray5)}.ibk-table__body::-webkit-scrollbar-thumb{background-color:var(--gray3);border-radius:2px}.ibk-table__container{border-collapse:collapse;width:100%}.ibk-table__row:not(:last-child){border-bottom:1px solid var(--gray4)}.ibk-table__row--heading{font-family:var(--fontGeometria);background-color:#f7f9f8}.ibk-table__cell{padding:15px 10px}.ibk-table__cell:first-child{padding-left:40px}.ibk-table--enumerate .ibk-table__cell:first-child{text-align:center;width:100px;font-size:12px;color:var(--gray2);font-weight:500}.ibk-table__cell:last-child{padding-right:40px}.ibk-table--selectable .ibk-table__row:not(.ibk-table__row--heading){cursor:pointer;transition:var(--fast)}.ibk-table--selectable .ibk-table__row:not(.ibk-table__row--heading):hover{background-color:var(--gray5)}.ibk-table--selectable.ibk-table--enumerate .ibk-table__cell:nth-child(2){width:50px;text-align:center}.ibk-table--selectable:not(.ibk-table--enumerate) .ibk-table__cell:nth-child(1){width:100px;text-align:center}.ibk-table__footer{position:relative;height:48px;margin-top:20px;display:flex;align-items:center;justify-content:center}.ibk-table__paginator{display:flex;align-items:center;position:absolute;top:0;right:0}.ibk-table__page-current{appearance:none;-webkit-appearance:none;-moz-appearance:none;border:1px solid var(--gray4);border-radius:4px;width:48px;padding:0 5px;height:48px;outline:none;text-align:center;font-family:var(--fontGeometria);font-weight:500;font-size:16px;margin-right:7px;transition:var(--fast)}.ibk-table__page-current:hover{border-color:var(--gray3)}.ibk-table__page-current:focus{border-color:var(--primaryGreen1);box-shadow:inset 0 0 0 0.5px var(--primaryGreen1)}.ibk-table__page-total{user-select:none}.ibk-table__page-total strong{font-weight:600}.ibk-table__page-prev,.ibk-table__page-next{font-size:12px;width:50px;text-align:center;cursor:pointer;color:var(--primaryGreen1)}.ibk-table__page-prev:active,.ibk-table__page-next:active{transform:translateY(1px)}.ibk-table__page-prev--disabled,.ibk-table__page-next--disabled{pointer-events:none;color:var(--gray3)}.ibk-table__rows-selector{position:absolute;top:0;left:0}.ibk-table__rows-dropdown{display:inline-block;width:80px;margin-right:7px}.ibk-table__rows-dropdown .ibk-dropdown__error-message{display:none}.ibk-table__cell-actions{min-width:130px;max-width:130px;width:130px}.ibk-table__action{color:var(--primaryGreen1);font-size:16px;display:inline-block;vertical-align:middle}.ibk-table__action:active{transform:translateY(1px)}.ibk-table__action:not(:last-child){margin-right:10px}";

const IbkTable = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.onselect = index.createEvent(this, "onselect", 7);
    this.ondetail = index.createEvent(this, "ondetail", 7);
    this.onedit = index.createEvent(this, "onedit", 7);
    this.ondelete = index.createEvent(this, "ondelete", 7);
    /** Se eliminará el estilo por defecto de la primera fila */
    this.notHeading = false;
    /** Agregará una columna al inicio con un botón para selección  */
    this.selectable = false;
    /** Define si se mostrará una numeración por cada fila */
    this.enumerate = false;
    /** Define cuantas filas se mostrarán por página */
    this.rowsPerPage = 5;
    /** Define la página actual del paginador */
    this.currentPage = 1;
    /** Define si se mostrará un resumen de filas en la parte inferior */
    this.showInfo = false;
    /** Define si se mostrará el selector de filas */
    this.rowsSelector = false;
    /** Define los rangos que se podrán seleccionar en el selector de filas
     * Se ingresará como valor números separados por comas
     * Si se desea que el la última opción sea mostrar todas las filas se colocará "all", por ejm: "5,10,all"
     */
    this.rowsToShow = "5,10,15,20,all";
    /** Especifica si la columna a ordenar tiene un tipo de dato concreto
     * Los valores pueden ser 'text', 'date' o 'number'
     * Por defecto se ordenará con el tipo texto
     * Si el tipo es date, la fecha deberá estar en formato dd/mm/yyyy
     */
    this.sortDataType = 'text';
    /** Almacena los índices seleccionados de la tabla */
    this._tempIndexes = new Array();
    /** Almacenará toda la información de la tabla */
    this._tableInfo = new Array();
    /** Almacenará la información a mostrar en la tabla (página actual) */
    this._currentTableInfo = new Array();
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return utils.modifiersToClass('ibk-table', [
        { selectable: this.selectable },
        { enumerate: this.enumerate }
      ]);
    };
    /** A partir de la tabla creada por el usuario, se creará un objeto con la información de la tabla */
    this.createObjectFromHtml = () => {
      const table = this.host.querySelector('table');
      const rows = table.querySelectorAll('tr');
      rows.forEach((row, index) => {
        const rowInfo = {};
        const cells = row.querySelectorAll('th, td');
        if (this.columnOfId) {
          rowInfo.id = (!this.notHeading && index > 0 || this.notHeading) ? cells[this.columnOfId - 1].innerHTML : 0;
        }
        else {
          rowInfo.id = !this.notHeading ? index : (index + 1);
        }
        rowInfo.cells = [];
        if (this.enumerate) {
          if (!this.notHeading) {
            rowInfo.cells.push(index > 0 ? index.toString() : '');
          }
          else {
            rowInfo.cells.push((index + 1).toString());
          }
        }
        if (this.selectable) {
          const checkboxNode = document.createElement('ibk-checkbox');
          checkboxNode.setAttribute('value', rowInfo.id);
          checkboxNode.setAttribute('icon-only', '');
          checkboxNode.classList.add('ibk-table__selector');
          rowInfo.cells.push(checkboxNode.outerHTML);
        }
        cells.forEach((cell) => {
          rowInfo.cells.push(cell.innerHTML.trim());
        });
        if (this.actions) {
          if (!this.notHeading && index == 0) {
            rowInfo.cells.push('<th class="ibk-table__cell">Acciones</th>');
          }
          if (!this.notHeading && index > 0 || this.notHeading) {
            rowInfo.cells.push(this.addActions(rowInfo.id));
          }
        }
        this._tableInfo.push(rowInfo);
      });
      this.sortData();
    };
    this.drawTable = () => {
      const table = this.host.querySelector('table');
      table.innerHTML = '';
      table.classList.add('ibk-table__container');
      if (this.paginator) {
        const start = !this.notHeading ? (this.currentPage * this.rowsPerPage) - this.rowsPerPage + 1 : (this.currentPage * this.rowsPerPage) - this.rowsPerPage;
        const end = !this.notHeading ? (this.currentPage * this.rowsPerPage) + 1 : (this.currentPage * this.rowsPerPage);
        this._currentTableInfo = this._tableInfo.slice(start, end);
        !this.notHeading && this._currentTableInfo.unshift(this._tableInfo[0]);
      }
      else {
        this._currentTableInfo = this._tableInfo;
      }
      this._currentTableInfo.forEach((rows, index) => {
        const rowNode = document.createElement('tr');
        rowNode.classList.add('ibk-table__row');
        !this.notHeading && index == 0 && rowNode.classList.add('ibk-table__row--heading');
        rows.cells.forEach((cell, i) => {
          const cellNode = document.createElement((!this.notHeading && index == 0) ? 'th' : 'td');
          cellNode.innerHTML = cell;
          cellNode.classList.add('ibk-table__cell');
          if (!this.notHeading && i == rows.cells.length - 1) {
            cellNode.classList.add('ibk-table__cell-actions');
          }
          rowNode.appendChild(cellNode);
        });
        table.appendChild(rowNode);
      });
      this.selectRow();
      this.emitAction();
    };
    /** Función que se ejecuta al seleccionar alguna fila de la tabla */
    this.selectRow = () => {
      const checkboxes = this.host.querySelectorAll('ibk-checkbox');
      checkboxes.forEach((check) => {
        check.addEventListener('onchecked', (e) => {
          if (!this.notHeading && e.detail.value == '0') {
            this._tempIndexes = new Array();
            const rows = this.host.querySelectorAll('.ibk-table__row');
            rows.forEach((row, index) => {
              if (e.detail.checked) {
                if (index != 0) {
                  const id = row.querySelector('.ibk-table__selector').getAttribute('value');
                  this._tempIndexes.push(id);
                  row.querySelector('.ibk-table__selector').setAttribute('checked', '');
                }
              }
              else {
                row.querySelector('.ibk-table__selector').removeAttribute('checked');
              }
            });
          }
          else if ((e.detail.value == '0' && this.notHeading) || e.detail.value != '0') {
            if (!this.notHeading) {
              checkboxes[0].removeAttribute('checked');
            }
            if (e.detail.checked) {
              this._tempIndexes.push(e.detail.value);
            }
            else {
              const idx = this._tempIndexes.indexOf(e.detail.value);
              this._tempIndexes.splice(idx, 1);
            }
          }
          this.onselect.emit(this._tempIndexes);
        });
      });
    };
    /** Configuración del paginador */
    this.configPaginator = () => {
      if (!this._pages) {
        const bodyTable = !this.notHeading ? this._tableInfo.length - 1 : this._tableInfo.length;
        this._pages = Math.ceil(bodyTable / this.rowsPerPage);
      }
      if (this.currentPage >= this._pages) {
        this.currentPage = this._pages;
      }
      else if (this.currentPage < 1) {
        this.currentPage = 1;
      }
    };
    /** Función que maneja el avance o retroceso de las páginas */
    this.handlerPaginator = (action) => {
      if (action == 'next') {
        this.currentPage++;
      }
      else {
        this.currentPage--;
      }
      const start = !this.notHeading ? (this.currentPage * this.rowsPerPage) - this.rowsPerPage + 1 : (this.currentPage * this.rowsPerPage) - this.rowsPerPage;
      const end = !this.notHeading ? (this.currentPage * this.rowsPerPage) + 1 : (this.currentPage * this.rowsPerPage);
      this._currentTableInfo = new Array();
      this._currentTableInfo = this._tableInfo.slice(start, end);
      !this.notHeading && this._currentTableInfo.unshift(this._tableInfo[0]);
      this.drawTable();
    };
    /** Validar que se ingrese un número en el campo de texto del paginador */
    this.validateEntryPage = e => {
      if (!utils.regexValidators.number.test(e.key) && (e.keyCode != 8 && e.keyCode != 9) && !(e.keyCode >= 37 && e.keyCode <= 40)) {
        e.preventDefault();
      }
    };
    /** Función que se ejecuta al escribir manualmente la página */
    this.editPage = e => {
      const t = e.target;
      const newPage = t.value;
      if (newPage < 1) {
        this.currentPage = 1;
      }
      else if (newPage > this._pages) {
        this.currentPage = this._pages;
      }
      else {
        this.currentPage = newPage;
      }
      const field = this.host.querySelector('.ibk-table__page-total');
      field.value = this.currentPage.toString();
      this.drawTable();
    };
    this.setRowsDropdown = () => {
      setTimeout(() => {
        const dropdown = this.host.querySelector('.ibk-table__rows-dropdown');
        this.rowsToShow.split(',').forEach((number, index) => {
          const child = document.createElement('ibk-dropdown-item');
          child.setAttribute('code', number == 'all' ? this._tableInfo.length.toString() : number);
          child.setAttribute('label', number == 'all' ? 'Todos' : number);
          index == 0 && child.setAttribute('selected', '');
          dropdown.appendChild(child);
        });
        dropdown.addEventListener('onchange', (e) => {
          this.rowsPerPage = parseInt(e.detail.code);
          const bodyTable = !this.notHeading ? this._tableInfo.length - 1 : this._tableInfo.length;
          this._pages = Math.ceil(bodyTable / this.rowsPerPage);
          this.drawTable();
        });
      }, 10);
    };
    /** Función que ordena las filas de la tabla dependiendo del dato enviado en el parámetro sort */
    this.sortData = () => {
      if (this.sort) {
        const tempTable = this._tableInfo.slice();
        const firstRow = !this.notHeading ? tempTable.shift() : null;
        const sortData = {
          id: parseInt(this.sort.split(',')[0]),
          type: this.sort.split(',')[1]
        };
        if (this.selectable && this.enumerate) {
          sortData.id++;
        }
        else if ((!this.selectable && this.enumerate) || (this.selectable && !this.enumerate)) ;
        else if (!this.selectable && !this.enumerate) {
          sortData.id--;
        }
        tempTable.sort((a, b) => {
          let compare1, compare2;
          if (this.sortDataType == 'text') {
            compare1 = a.cells[sortData.id].toLowerCase();
            compare2 = b.cells[sortData.id].toLowerCase();
          }
          else if (this.sortDataType == 'number') {
            compare1 = parseInt(a.cells[sortData.id]);
            compare2 = parseInt(b.cells[sortData.id]);
          }
          else if (this.sortDataType == 'date') {
            let dateA = a.cells[sortData.id].split('/');
            let dateB = b.cells[sortData.id].split('/');
            compare1 = new Date(dateA[2], dateA[1], dateA[0]);
            compare2 = new Date(dateB[2], dateB[1], dateB[0]);
          }
          if (sortData.type == 'asc') {
            return compare1 <= compare2 ? -1 : 1;
          }
          else {
            return compare1 > compare2 ? -1 : 1;
          }
        });
        this._tableInfo = tempTable;
        !this.notHeading && this._tableInfo.unshift(firstRow);
      }
    };
    /** Función que agrega la columna de acciones dependiendo del dato enviado en el parámetro actions */
    this.addActions = (id) => {
      if (this.actions) {
        const actions = this.actions.split(',');
        let htmlActions = '';
        actions.forEach((action) => {
          const actionNode = document.createElement('i');
          actionNode.classList.add('ibk-table__action');
          actionNode.setAttribute('data-id', id);
          actionNode.setAttribute('data-action', action);
          if (action == 'detail') {
            actionNode.classList.add('icon-m-eye-on', 'ibk-table__action--detail');
          }
          else if (action == 'edit') {
            actionNode.classList.add('icon-m-edit', 'ibk-table__action--edit');
          }
          else if (action == 'delete') {
            actionNode.classList.add('icon-m-trash', 'ibk-table__action--delete');
          }
          htmlActions += actionNode.outerHTML;
        });
        return htmlActions;
      }
    };
    this.emitAction = () => {
      const actions = this.host.querySelectorAll('.ibk-table__action');
      actions.forEach((action) => {
        action.addEventListener('click', e => {
          const t = e.target;
          const action = t.getAttribute('data-action');
          const id = t.getAttribute('data-id');
          if (action == 'detail') {
            this.ondetail.emit(id);
          }
          else if (action == 'edit') {
            this.onedit.emit(id);
          }
          else if (action == 'delete') {
            this.ondelete.emit(id);
          }
        });
      });
    };
    /** Función que filtrará la información de la tabla basado en el valor de la propiedad filteredText */
    this.setFilteredText = () => {
    };
  }
  componentWillLoad() {
    this.createObjectFromHtml();
    this.drawTable();
    this.configPaginator();
    this.setRowsDropdown();
  }
  render() {
    return (index.h("div", { class: this.containerClass() }, index.h("div", { class: "ibk-table__body" }, index.h("slot", null)), this.paginator &&
      index.h("div", { class: "ibk-table__footer" }, this.rowsSelector &&
        index.h("div", { class: "ibk-table__rows-selector" }, index.h("ibk-dropdown", { class: "ibk-table__rows-dropdown" }), index.h("span", null, "\u00F3rdenes por p\u00E1gina")), this.showInfo &&
        index.h("div", { class: "ibk-table__showing" }, index.h("span", null, "Mostrando", index.h("strong", null, " ", (this.currentPage * this.rowsPerPage) - this.rowsPerPage + 1, " - ", (this.currentPage * this.rowsPerPage > this._tableInfo.length ? this._tableInfo.length : this.currentPage * this.rowsPerPage)), " de", index.h("strong", null, " ", !this.notHeading ? this._tableInfo.length - 1 : this._tableInfo.length, " "), "\u00F3rdenes")), index.h("div", { class: "ibk-table__paginator" }, index.h("i", { class: "ibk-table__page-prev icon-xs-arrow-left" + (this.currentPage == 1 ? ' ibk-table__page-prev--disabled' : ''), onClick: () => this.handlerPaginator('prev') }), index.h("input", { class: "ibk-table__page-current", type: "text", value: this.currentPage, onKeyDown: this.validateEntryPage, onInput: this.editPage }), index.h("span", { class: "ibk-table__page-total" }, "de ", index.h("strong", null, this._pages)), index.h("i", { class: "ibk-table__page-next icon-xs-arrow-right" + (this.currentPage == this._pages ? ' ibk-table__page-next--disabled' : ''), onClick: () => this.handlerPaginator('next') })))));
  }
  get host() { return index.getElement(this); }
};
IbkTable.style = tableCss;

const tagCss = ".ibk-tag{box-sizing:border-box;background-color:var(--primaryGreen1);display:inline-flex;align-items:center;justify-content:center;text-align:center;border-radius:30px;padding:10px 15px;border:1px solid transparent;cursor:default}.ibk-tag *{box-sizing:border-box}.ibk-tag__text{color:white;font-family:var(--fontGeometria);font-weight:500;font-size:14px}.ibk-tag__icon{color:white}.ibk-tag--icon-left .ibk-tag__icon{margin-right:7px}.ibk-tag--icon-right .ibk-tag__icon{order:2;margin-left:7px}.ibk-tag--outline{background-color:transparent;border-color:var(--primaryGreen1)}.ibk-tag--outline .ibk-tag__text,.ibk-tag--outline .ibk-tag__icon{color:var(--primaryGreen1)}";

const IbkTag = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /** Define la posición del ícono a mostrar */
    this.iconPosition = 'left';
    /** El tag solo usará el color en el borde */
    this.outline = false;
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return utils.modifiersToClass('ibk-tag', [
        `icon-${this.iconPosition}`,
        { outline: this.outline }
      ]);
    };
  }
  render() {
    var _a, _b;
    return (index.h("div", { class: this.containerClass(), style: { backgroundColor: !this.outline && this.color, borderColor: this.outline && this.color, width: `${this.width}px` } }, this.icon && index.h("i", { class: this.icon + ' ibk-tag__icon', style: { color: (_a = this.textColor) !== null && _a !== void 0 ? _a : (this.outline && this.color) } }), index.h("span", { class: "ibk-tag__text", style: { color: (_b = this.textColor) !== null && _b !== void 0 ? _b : (this.outline && this.color) } }, this.text)));
  }
};
IbkTag.style = tagCss;

const textfieldCss = ".ibk-textfield{width:100%;box-sizing:border-box}.ibk-textfield *{box-sizing:border-box}.ibk-textfield__label{font-family:var(--fontGeometria);font-size:14px;padding-bottom:5px;display:block;font-weight:500;color:var(--gray1)}.ibk-textfield__subtitle{font-family:var(--fontMontserrat);color:var(--grayText);font-size:14px;font-weight:500;padding-bottom:7px;display:block}.ibk-textfield__input{display:flex;align-items:center;width:100%;border:1px solid var(--gray4);border-radius:4px;height:48px;transition:var(--fast);background-color:white}@media screen and (max-width: 360px){.ibk-textfield__input{height:44px}}.ibk-textfield__input:hover{border-color:var(--gray3)}.ibk-textfield__value{width:100%;appearance:none;-webkit-appearance:none;-moz-appearance:none;border:none;outline:none;display:block;height:100%;padding:0 15px;font-family:var(--fontGeometria);font-size:16px;font-weight:500;color:var(--grayText);background-color:transparent}.ibk-textfield__value::placeholder{color:var(--gray2);font-weight:400}.ibk-textfield__value::-ms-reveal,.ibk-textfield__value::-ms-clear{display:none}.ibk-textfield__value::-webkit-outer-spin-button,.ibk-textfield__value::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}.ibk-textfield--focus .ibk-textfield__input{border-color:var(--primaryGreen1);box-shadow:inset 0 0 0 0.5px var(--primaryGreen1)}.ibk-textfield__trailing-icon{padding-right:15px;color:var(--primaryGreen1);cursor:text}.ibk-textfield__leading-icon{padding-left:15px;color:var(--primaryGreen1);cursor:text}.ibk-textfield--erasable .ibk-textfield__trailing-icon{color:var(--gray1)}.ibk-textfield--password .ibk-textfield__trailing-icon,.ibk-textfield--erasable .ibk-textfield__trailing-icon{cursor:pointer}.ibk-textfield--password .ibk-textfield__trailing-icon:active,.ibk-textfield--erasable .ibk-textfield__trailing-icon:active{transform:translateY(1px)}.ibk-textfield--error .ibk-textfield__input{border-color:var(--extendedWatermelon1)}.ibk-textfield--error.ibk-textfield--focus .ibk-textfield__input{box-shadow:inset 0 0 0 0.5px var(--extendedWatermelon1)}.ibk-textfield--error .ibk-textfield__trailing-icon,.ibk-textfield--error .ibk-textfield__leading-icon{color:var(--extendedWatermelon1)}.ibk-textfield__error-message{font-family:var(--fontMontserrat);font-size:12px;color:var(--extendedWatermelon1);font-weight:500;margin-top:7px;display:block;min-height:15px}.ibk-textfield--disabled{cursor:default;pointer-events:none}.ibk-textfield--disabled .ibk-textfield__input{background-color:var(--gray5)}";

const IbkTextfield = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.onchange = index.createEvent(this, "onchange", 7);
    this.onfocus = index.createEvent(this, "onfocus", 7);
    /** Tipo de contenido que se ingresará en el campo de texto */
    this.type = 'text';
    /** Cuando se encuentra dentro de un "ibk-form" al hacer submit si el campo de texto se encuentra vacío, mostrará un mensaje de error */
    this.required = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = 'Este campo es requerido';
    /** Se mostrará un mensaje de error */
    this.error = false;
    /** Personaliza el mensaje de error */
    this.errorMessage = 'Por favor, ingrese este campo correctamente';
    /** Contenido del campo de texto */
    this.value = '';
    /** Define si el textfield no contará con manejo de errores. Se omitirá el espacio generado para el mensaje de error */
    this.noHandlingError = false;
    /** Muestra un icono a la izquierda con una X que sirve para borrar el contenido del campo de texto */
    this._erasable = false;
    /** Estado activo o inactivo del campo de texto */
    this._focus = false;
    /** Estado que determina si la contraseña está visible o no */
    this._showingPwd = false;
    /** Configura el tipo de campo de texto en base a la configuración del componente */
    this.setInputType = () => {
      let type = '';
      if (this.type == 'password' && !this._showingPwd) {
        type = 'password';
      }
      else if (this.type == 'date') {
        type = this.type;
      }
      else {
        type = 'text';
      }
      return type;
    };
    /** Define el máximo de caracteres en base a la configuración del componente */
    this.setMaxLength = () => {
      let length = 0;
      if (this.type == 'expiration') {
        length = 5;
      }
      else if (this.type == 'cvv') {
        length = 4;
      }
      else if (this.type == 'dni') {
        length = 8;
      }
      else if (this.type == 'document') {
        length = 16;
      }
      else if (this.type == 'phone') {
        length = 9;
      }
      return length;
    };
    /** Configura el icono del lado izquierdo en base a la configuración del componente */
    this.setTrailingIcon = () => {
      let icon = '';
      if (this.type == 'password') {
        icon = this._showingPwd ? 'icon-m-eye-off' : 'icon-m-eye-on';
      }
      else if (this._erasable) {
        icon = 'icon-m-status-error';
      }
      else if (this.trailingIcon) {
        icon = this.trailingIcon;
      }
      return icon;
    };
    /** Determina la función a realizar en base al icono actual */
    this.trailingIconFunction = () => {
      if (this.type == 'password') {
        this._showingPwd = !this._showingPwd;
      }
      else if (this._erasable) {
        const input = this.host.querySelector('.ibk-textfield__value');
        input.value = '';
        this._erasable = false;
      }
    };
    /** Determina el mensaje de error a mostrar en base a la configuración del componente */
    this.setErrorMessage = () => {
      let msg = '';
      if (this.required && this.error && this.value.length == 0) {
        msg = this.requiredMessage;
      }
      else if (this.error) {
        msg = this.errorMessage;
      }
      return msg;
    };
    /** Escucha y emite el evento editing cuando cambia el contenido */
    this.onInputChange = (e) => {
      const t = e.target;
      this.value = t.value;
      if (this.value != '') {
        this.host.removeAttribute('error');
        this._erasable = true;
      }
      else {
        this._erasable = false;
      }
      if (this.type == 'expiration' && t.value.length == 2 && this._keyCode != 8) {
        this.value += '/';
      }
      if (this._grouper != null) {
        this._grouper.removeAttribute('error');
      }
      this.onchange.emit(t.value);
    };
  }
  componentWillLoad() {
    this._grouper = this.host.closest('ibk-form-group');
  }
  onInputFocusIn() {
    this._focus = true;
    this.onfocus.emit('in');
  }
  onInputFocusOut() {
    this._focus = false;
    this.onfocus.emit('out');
    /** Validación para fecha de expiración */
    if (this.type == 'expiration' && this.value.length == 5) {
      const exp = this.value.split('/');
      const currentYear = new Date().getFullYear().toString();
      const formatYear = currentYear.slice(2);
      if (parseInt(exp[0]) > 12 || parseInt(exp[1]) < parseInt(formatYear)) {
        this.host.setAttribute('error', '');
      }
    }
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return utils.modifiersToClass('ibk-textfield', [
      this.type,
      { focus: this._focus },
      { erasable: this._erasable },
      { error: this.error },
      { disabled: this.disabled }
    ]);
  }
  onKeyDown(e) {
    this._keyCode = e.keyCode;
    if (['expiration', 'cvv', 'dni'].includes(this.type) && !utils.regexValidators.number.test(e.key) && (this._keyCode != 8 && this._keyCode != 9)) {
      e.preventDefault();
    }
    else if (this.type == 'number' && !utils.regexValidators.numberFormat.test(e.key) && (this._keyCode != 8 && this._keyCode != 9)) {
      e.preventDefault();
    }
  }
  render() {
    var _a;
    return (index.h("div", { class: this.containerClass(), style: { width: this.width + 'px' } }, this.label && index.h("span", { class: "ibk-textfield__label" }, this.label), this.subtitle && index.h("span", { class: "ibk-textfield__subtitle" }, this.subtitle), index.h("label", { class: "ibk-textfield__input" }, this.leadingIcon && index.h("i", { class: 'ibk-textfield__leading-icon ' + this.leadingIcon }), index.h("input", { class: "ibk-textfield__value", type: this.setInputType(), placeholder: this.placeholder, maxLength: (_a = this.maxLength) !== null && _a !== void 0 ? _a : (this.setMaxLength() > 0 ? this.setMaxLength() : null), value: this.value, onInput: this.onInputChange }), this.setTrailingIcon() != '' && index.h("i", { class: 'ibk-textfield__trailing-icon ' + this.setTrailingIcon(), onClick: this.trailingIconFunction })), !this.noHandlingError && index.h("span", { class: "ibk-textfield__error-message" }, this.setErrorMessage())));
  }
  get host() { return index.getElement(this); }
};
IbkTextfield.style = textfieldCss;

exports.ibk_button = IbkButton;
exports.ibk_checkbox = IbkCheckbox;
exports.ibk_dropdown = IbkDropdown;
exports.ibk_dropdown_item = IbkDropdownItem;
exports.ibk_form = IbkForm;
exports.ibk_form_group = IbkFormGroup;
exports.ibk_table = IbkTable;
exports.ibk_tag = IbkTag;
exports.ibk_textfield = IbkTextfield;
