'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-9f949333.js');
const utils = require('./utils-60214ddc.js');

const searchbarCss = ".ibk-searchbar{box-sizing:border-box;color:var(--grayText);position:relative}.ibk-searchbar *{box-sizing:border-box}.ibk-searchbar__label{font-family:var(--fontGeometria);font-size:14px;padding-bottom:5px;display:block;font-weight:500;color:var(--gray1)}.ibk-searchbar__subtitle{font-family:var(--fontMontserrat);color:var(--grayText);font-size:14px;font-weight:500;padding-bottom:7px;display:block}.ibk-searchbar__input{display:flex;align-items:center;width:100%;border:1px solid var(--gray4);border-radius:4px;background-color:white;transition:var(--fast);cursor:text}.ibk-searchbar__input:hover{border-color:var(--gray3)}.ibk-searchbar__icon-search{color:var(--grayText);font-size:20px;display:block;height:100%;min-width:46px;text-align:center;cursor:text}.ibk-searchbar__value{width:100%;appearance:none;-webkit-appearance:none;-moz-appearance:none;outline:none;border:none;height:46px;background-color:transparent;font-family:var(--fontGeometria);font-weight:500;font-size:16px;color:var(--grayText)}.ibk-searchbar__icon-clear{min-width:46px;cursor:pointer;color:var(--gray1);text-align:center}.ibk-searchbar__icon-clear:active{transform:translateY(1px)}.ibk-searchbar__value::placeholder{color:var(--gray2);font-weight:400}.ibk-searchbar--focus .ibk-searchbar__input{border-color:var(--primaryGreen1);box-shadow:inset 0 0 0 0.5px var(--primaryGreen1)}.ibk-searchbar--disabled .ibk-searchbar__input{pointer-events:none;background-color:var(--gray5)}.ibk-searchbar__results{position:absolute;min-width:max-content;width:100%;background-color:white;border:1px solid var(--gray4);top:calc(100% - 1px);border-radius:0 0 4px 4px;transition:var(--fast);display:none}ibk-search-result:not(:last-child) .ibk-search-result{border-bottom:1px solid var(--gray4)}.ibk-searchbar--open .ibk-searchbar__input{border-radius:4px 4px 0 0}.ibk-searchbar--open .ibk-searchbar__results{display:block;border-top-color:var(--primaryGreen1)}";

const IbkSearchbar = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.onsearch = index.createEvent(this, "onsearch", 7);
    this.onedit = index.createEvent(this, "onedit", 7);
    /** Texto de ayuda dentro del searchbar */
    this.placeholder = 'Buscar';
    /** Define un valor predeterminado para el searchbar */
    this.value = '';
    /** Define si el searchbar muestra un icono de carga mientras se hace la consulta */
    this.loading = false;
    /** Función que se ejecuta al escribir en el searchbar */
    this.search = (e) => {
      const t = e.target;
      this.value = t.value;
      this.onedit.emit(this.value);
      if (this.value.length == 3) {
        if (this.value != this._lastSearched) {
          this._lastSearched = this.value;
          this.onsearch.emit(this.value);
        }
      }
      else if (this.value.length > 3) {
        const results = this.host.querySelectorAll('ibk-search-result');
        results.forEach((result) => {
          const label = utils.convertToPlainString(result.getAttribute('label'));
          if (label.search(this.value) < 0) {
            result.setAttribute('hide', '');
          }
          else {
            result.removeAttribute('hide');
          }
          const searchWords = this.value.split(' ');
          const resultWords = label.split(' ');
          if (searchWords.length > 1 && resultWords.length > 1) {
            searchWords.forEach((word) => {
              resultWords.forEach((resultWord) => {
                const indexSearch = resultWord.trim().search(word);
                if (indexSearch < 0) {
                  result.setAttribute('hide', '');
                }
                else {
                  console.log(word, resultWord, indexSearch);
                  result.removeAttribute('hide');
                }
              });
            });
          }
        });
      }
    };
  }
  onSearchbarFocusIn() {
    this._focus = true;
  }
  onSearchbarFocusOut() {
    this._focus = false;
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return utils.modifiersToClass('ibk-searchbar', [
      { focus: this._focus },
      { disabled: this.disabled },
      { open: this.value.length >= 3 && this._focus }
    ]);
  }
  render() {
    return (index.h("div", { class: this.containerClass(), style: { width: this.width + 'px' } }, this.label && index.h("span", { class: "ibk-searchbar__label" }, this.label), this.subtitle && index.h("span", { class: "ibk-searchbar__subtitle" }, this.subtitle), index.h("label", { class: "ibk-searchbar__input" }, index.h("i", { class: "ibk-searchbar__icon-search icon-m-search" }), index.h("input", { class: "ibk-searchbar__value", type: "text", onInput: this.search, placeholder: this.placeholder, value: this.value }), this.value.length >= 1 && index.h("i", { class: "ibk-searchbar__icon-clear icon-m-status-error", onClick: () => this.value = '' })), index.h("div", { class: "ibk-searchbar__results" }, this.value.length == 3 && index.h("slot", null))));
  }
  get host() { return index.getElement(this); }
};
IbkSearchbar.style = searchbarCss;

exports.ibk_searchbar = IbkSearchbar;
