import { Component, Element, Event, h, Listen, Prop, State } from "@stencil/core";
import { modifiersToClass, convertToPlainString } from '../../utils/utils';
export class IbkSearchbar {
  constructor() {
    /** Texto de ayuda dentro del searchbar */
    this.placeholder = 'Buscar';
    /** Define un valor predeterminado para el searchbar */
    this.value = '';
    /** Define si el searchbar muestra un icono de carga mientras se hace la consulta */
    this.loading = false;
    /** Función que se ejecuta al escribir en el searchbar */
    this.search = (e) => {
      const t = e.target;
      this.value = t.value;
      this.onedit.emit(this.value);
      if (this.value.length == 3) {
        if (this.value != this._lastSearched) {
          this._lastSearched = this.value;
          this.onsearch.emit(this.value);
        }
      }
      else if (this.value.length > 3) {
        const results = this.host.querySelectorAll('ibk-search-result');
        results.forEach((result) => {
          const label = convertToPlainString(result.getAttribute('label'));
          if (label.search(this.value) < 0) {
            result.setAttribute('hide', '');
          }
          else {
            result.removeAttribute('hide');
          }
          const searchWords = this.value.split(' ');
          const resultWords = label.split(' ');
          if (searchWords.length > 1 && resultWords.length > 1) {
            searchWords.forEach((word) => {
              resultWords.forEach((resultWord) => {
                const indexSearch = resultWord.trim().search(word);
                if (indexSearch < 0) {
                  result.setAttribute('hide', '');
                }
                else {
                  console.log(word, resultWord, indexSearch);
                  result.removeAttribute('hide');
                }
              });
            });
          }
        });
      }
    };
  }
  onSearchbarFocusIn() {
    this._focus = true;
  }
  onSearchbarFocusOut() {
    this._focus = false;
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return modifiersToClass('ibk-searchbar', [
      { focus: this._focus },
      { disabled: this.disabled },
      { open: this.value.length >= 3 && this._focus }
    ]);
  }
  render() {
    return (h("div", { class: this.containerClass(), style: { width: this.width + 'px' } },
      this.label && h("span", { class: "ibk-searchbar__label" }, this.label),
      this.subtitle && h("span", { class: "ibk-searchbar__subtitle" }, this.subtitle),
      h("label", { class: "ibk-searchbar__input" },
        h("i", { class: "ibk-searchbar__icon-search icon-m-search" }),
        h("input", { class: "ibk-searchbar__value", type: "text", onInput: this.search, placeholder: this.placeholder, value: this.value }),
        this.value.length >= 1 && h("i", { class: "ibk-searchbar__icon-clear icon-m-status-error", onClick: () => this.value = '' })),
      h("div", { class: "ibk-searchbar__results" }, this.value.length == 3 && h("slot", null))));
  }
  static get is() { return "ibk-searchbar"; }
  static get originalStyleUrls() { return {
    "$": ["searchbar.css"]
  }; }
  static get styleUrls() { return {
    "$": ["searchbar.css"]
  }; }
  static get properties() { return {
    "placeholder": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Texto de ayuda dentro del searchbar"
      },
      "attribute": "placeholder",
      "reflect": false,
      "defaultValue": "'Buscar'"
    },
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Texto de ayuda encima del searchbar"
      },
      "attribute": "label",
      "reflect": false
    },
    "subtitle": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Se incluye el subtitulo entre el label (si existiera) y el searchbar"
      },
      "attribute": "subtitle",
      "reflect": false
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "El searchbar no se podr\u00E1 usar"
      },
      "attribute": "disabled",
      "reflect": false
    },
    "width": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Configura un ancho fijo para el componente"
      },
      "attribute": "width",
      "reflect": false
    },
    "value": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Define un valor predeterminado para el searchbar"
      },
      "attribute": "value",
      "reflect": false,
      "defaultValue": "''"
    },
    "loading": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Define si el searchbar muestra un icono de carga mientras se hace la consulta"
      },
      "attribute": "loading",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get states() { return {
    "_focus": {}
  }; }
  static get events() { return [{
      "method": "onsearch",
      "name": "onsearch",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emite un evento cuando el searchbar contenga 3 caracteres para realizar la b\u00FAsqueda"
      },
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      }
    }, {
      "method": "onedit",
      "name": "onedit",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emite un evento al escribir"
      },
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      }
    }]; }
  static get elementRef() { return "host"; }
  static get listeners() { return [{
      "name": "focusin",
      "method": "onSearchbarFocusIn",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "focusout",
      "method": "onSearchbarFocusOut",
      "target": undefined,
      "capture": false,
      "passive": false
    }]; }
}
